__author__ = 'Kyle'

speed_of_light = 299792458
R_ideal = 0.0821
gravity = 9.81


def ideal_gas_law(p=None, v=None, n=None, t=None, precision=2):
    """Find the pressure, volume, amount, or temperature of a gas.

    Calculate pressure, volume, amount, or temperature of a gas based on the parameters.
    Parameters are p (pressure in atm), v (volume in L), n (amount in moles), t (Temperature in K), precision
    (The amount of decimal places to return).
    This returns the value that was not given or None if more or less than 3 values are given.
    """
    if [p, v, n, t].count(None) != 1:
        return None
    if p is None:
        return round((n * t * R_ideal) / v, precision)
    elif v is None:
        return round((n * t * R_ideal) / p, precision)
    elif n is None:
        return round((p * v) / (R_ideal * t), precision)
    elif t is None:
        return round((p * v) / (R_ideal * n), precision)


def gravitational_potential(m, h, precision=2):
    """Find the gravitational potential energy of an object.

    Calculate gravitational potential energy of an object with a mass, m (Kg), and a height, h (meters).
    This returns the gravitational potential energy of an object in J.
    """
    return round(gravity * m * h, precision)


def force(m, a, precision=2):
    """Find the force of a system.

    Calculate force of an object with mass, m (Kg) and an acceleration, a (m/s**2).
    This returns the force of an object in N.
    """
    return round(m * a, precision)


def acceleration(v, t, precision=2):
    """Find the acceleration of a system.

    Calculate acceleration of an object with change in velocity, v (m/s) and change in time, t (s).
    This returns the acceleration of an object in m/s**2.
    """
    return round(v / t, precision)